vdoc.api package | vdoc 0.19.0 documentation

Skip to content

# vdoc.api package

## Subpackages

- vdoc.api.dependencies package
  - Submodules
  - vdoc.api.dependencies.auth module
    - `require_authentication()`
  - Module contents
- vdoc.api.routes package
  - Submodules
  - vdoc.api.routes.plugins module
    - `get_router()`
  - vdoc.api.routes.project_categories module
    - `list_project_categories()`
  - vdoc.api.routes.projects module
    - `get_project_versions()`
    - `list_project_versions()`
    - `list_projects()`
    - `upload_project_version()`
  - vdoc.api.routes.version module
    - `get_app_version_route()`
  - Module contents

## Submodules

## vdoc.api.lifespan module

Defines the FastAPI lifespan and route loading.

vdoc.api.lifespan.routes_loader_lifespan(fastapi)

  Lifespan context manager for the FastAPI app.

  The order for mounting the routers is important. The frontend router must be the last one to ensure that all non-api or documentation requests are handled by the frontend.

  Parameters:

    fastapi (`FastAPI`) – The FastAPI app instance.

  Yields:

    None – No value is yielded.

  Return type:

    `AsyncGenerator`[`None`, `None`]

## Module contents

Contains the Rest API.

vdoc.api.create_app()

  Creates the FastAPI app instance.

  Return type:

    `FastAPI`

  Returns:

    The FastAPI app instance.

vdoc package
vdoc.api.dependencies package